[GRASS-SVN] r34574 - grass-addons/raster/r.rast4d/sql

svn_grass at osgeo.org svn_grass at osgeo.org
Thu Nov 27 18:26:55 EST 2008


Author: neteler
Date: 2008-11-27 18:26:55 -0500 (Thu, 27 Nov 2008)
New Revision: 34574

Modified:
   grass-addons/raster/r.rast4d/sql/create_raster_categorie_table.sql
   grass-addons/raster/r.rast4d/sql/create_raster_metadata_table.sql
   grass-addons/raster/r.rast4d/sql/create_raster_table.sql
   grass-addons/raster/r.rast4d/sql/create_temporal_raster_metadata_table.sql
Log:
changes some type declarations to be PostgreSQL compliant

Modified: grass-addons/raster/r.rast4d/sql/create_raster_categorie_table.sql
===================================================================
--- grass-addons/raster/r.rast4d/sql/create_raster_categorie_table.sql	2008-11-27 23:13:23 UTC (rev 34573)
+++ grass-addons/raster/r.rast4d/sql/create_raster_categorie_table.sql	2008-11-27 23:26:55 UTC (rev 34574)
@@ -3,7 +3,7 @@
 -- the specific column should be selected with a where statement, by default the column
 -- named "label" should be used
 CREATE TABLE TABLE_NAME (cat INTEGER PRIMARY KEY, -- the category number 
-			 value NUMERIC(25,15), -- the numerical value of the raster map using this category
+			 value NUMERIC, -- the numerical value of the raster map using this category
 			 label VARCHAR(500) -- the label of the category
                         );
 

Modified: grass-addons/raster/r.rast4d/sql/create_raster_metadata_table.sql
===================================================================
--- grass-addons/raster/r.rast4d/sql/create_raster_metadata_table.sql	2008-11-27 23:13:23 UTC (rev 34573)
+++ grass-addons/raster/r.rast4d/sql/create_raster_metadata_table.sql	2008-11-27 23:26:55 UTC (rev 34574)
@@ -1,6 +1,6 @@
 -- This script will create the table managing the metadata of one raster map
 CREATE TABLE TABLE_NAME (name VARCHAR(256) PRIMARY KEY, -- the name of the raster map
-                         projection CLOB , -- Projection information
+                         projection TEXT , -- Projection information
                          datatype VARCHAR(30), -- the map data type
 			 rows INTEGER, -- the number of rows
 			 cols INTEGER, -- the number of columns
@@ -15,10 +15,10 @@
 			 max NUMERIC(25,15), --the maximum value
 			 mtime DATE, -- the modification time of the current entry
 			 creator VARCHAR(30), -- the login of the creator
-                         data_source CLOB , -- the source of the raster map
-                         comments CLOB , -- comments 
-                         description CLOB , -- the raster map description
-                         additional_data CLOB -- further metadata
+                         data_source TEXT , -- the source of the raster map
+                         comments TEXT , -- comments 
+                         description TEXT , -- the raster map description
+                         additional_data TEXT -- further metadata
                         );
 -- this table is created once for all existing raster maps containing the actual metadata information
 -- and this table is created each time a new raster map is created containing the history of metadata

Modified: grass-addons/raster/r.rast4d/sql/create_raster_table.sql
===================================================================
--- grass-addons/raster/r.rast4d/sql/create_temporal_raster_metadata_table.sql	2008-11-27 23:13:23 UTC (rev 34573)
+++ grass-addons/raster/r.rast4d/sql/create_temporal_raster_metadata_table.sql	2008-11-27 23:26:55 UTC (rev 34574)
@@ -2,7 +2,7 @@
 -- the temporal raster map region is used with all registered raster map, independently which kind of region
 -- the registered raster maps have
 CREATE TABLE TABLE_NAME (name VARCHAR(256) PRIMARY KEY, -- the name of the temporal raster map
-                         projection CLOB , -- Projection information for this temporal data type
+                         projection TEXT , -- Projection information for this temporal data type
                          vtime_start DATE, -- start valid time
                          vtime_end DATE, -- end valid time
 			 vtime_duration DATE, -- the duration time
@@ -14,20 +14,20 @@
 			 cols INTEGER, -- the number of columns  of the temporal region
 			 raster_num INTEGER, -- the number of registered raster maps
 			 cell_num INTEGER, -- the number of temporal cell (rows * cols * raster_num)
-			 north NUMERIC(15,10), -- coordinates of the northern edge
-			 south NUMERIC(15,10), -- coordinates of the southern edge
-			 west NUMERIC(15,10), -- coordinates of the western edge
-			 east NUMERIC(15,10), -- coordinates of the eastern edge
-			 ns_res NUMERIC(15,10), -- resolution in north/south direction
-			 ew_res NUMERIC(15,10), -- resolution in east/west direction
-			 min NUMERIC(25,15), --the minimum value
-			 max NUMERIC(25,15), --the maximum value
+			 north NUMERIC, -- coordinates of the northern edge
+			 south NUMERIC, -- coordinates of the southern edge
+			 west NUMERIC, -- coordinates of the western edge
+			 east NUMERIC, -- coordinates of the eastern edge
+			 ns_res NUMERIC, -- resolution in north/south direction
+			 ew_res NUMERIC, -- resolution in east/west direction
+			 min NUMERIC, --the minimum value
+			 max NUMERIC, --the maximum value
 			 modification_time DATE, -- the modification time of the current temporal map 
 			 creator VARCHAR(30), -- the login of the creator
-                         data_source CLOB , -- the source of the temporal raster map
-                         comments CLOB , -- comments 
-                         description CLOB , -- the temporal raster map description
-                         additonal_data CLOB -- further metadata
+                         data_source TEXT , -- the source of the temporal raster map
+                         comments TEXT , -- comments 
+                         description TEXT , -- the temporal raster map description
+                         additonal_data TEXT -- further metadata
                         );
 -- this table is created once for all existing raster maps containing the actual metadata information
 -- and this table is created each time a new raster map is created containing the history of metadata



More information about the grass-commit mailing list
--- grass-addons/raster/r.rast4d/sql/create_raster_table.sql	2008-11-27 23:13:23 UTC (rev 34573)
+++ grass-addons/raster/r.rast4d/sql/create_raster_table.sql	2008-11-27 23:26:55 UTC (rev 34574)
@@ -3,7 +3,7 @@
 CREATE TABLE TABLE_NAME (name VARCHAR(256) PRIMARY KEY,
                          base_map VARCHAR(256) , -- the map of which this map is based on
                          reference_table VARCHAR(300), -- the table containing all raster map names which are using this map as base map
-			 color CLOB, -- the color information is stored as CLOB
+			 color TEXT, -- the color information is stored as TEXT
                          group_table VARCHAR(300), -- the table containing all group names in which this raster map is registered
                          temporal_table VARCHAR(300), -- the table containing all temporal raster map names 
 			 			      -- in which this raster map is registered

Modified: grass-addons/raster/r.rast4d/sql/create_temporal_raster_metadata_table.sql
===================================================================